You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@geode.apache.org by kh...@apache.org on 2017/05/30 22:18:57 UTC

geode git commit: GEODE-2974: Remove GemFire product name from message string

Repository: geode
Updated Branches:
  refs/heads/develop c08d70dd4 -> 2fb738157


GEODE-2974: Remove GemFire product name from message string

The error message now reports "Could not process command due to error."
followed by the decription of the error.


Project: http://git-wip-us.apache.org/repos/asf/geode/repo
Commit: http://git-wip-us.apache.org/repos/asf/geode/commit/2fb73815
Tree: http://git-wip-us.apache.org/repos/asf/geode/tree/2fb73815
Diff: http://git-wip-us.apache.org/repos/asf/geode/diff/2fb73815

Branch: refs/heads/develop
Commit: 2fb738157ac8b5c8e2e2fab03e3e87874f8e5bc3
Parents: c08d70d
Author: Ken Howe <kh...@pivotal.io>
Authored: Wed May 24 13:34:37 2017 -0700
Committer: Ken Howe <kh...@pivotal.io>
Committed: Tue May 30 15:15:40 2017 -0700

----------------------------------------------------------------------
 .../internal/cli/result/ResultBuilder.java          | 16 +++++++---------
 1 file changed, 7 insertions(+), 9 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/geode/blob/2fb73815/geode-core/src/main/java/org/apache/geode/management/internal/cli/result/ResultBuilder.java
----------------------------------------------------------------------
diff --git a/geode-core/src/main/java/org/apache/geode/management/internal/cli/result/ResultBuilder.java b/geode-core/src/main/java/org/apache/geode/management/internal/cli/result/ResultBuilder.java
index 6332540..94dbca0 100755
--- a/geode-core/src/main/java/org/apache/geode/management/internal/cli/result/ResultBuilder.java
+++ b/geode-core/src/main/java/org/apache/geode/management/internal/cli/result/ResultBuilder.java
@@ -22,9 +22,7 @@ import java.util.Collection;
 import java.util.List;
 
 /**
- * 
- * 
- * @since GemFire 7.0
+ * Provides methods for creating {@link Result} objects to return from Gfsh command functions
  */
 public class ResultBuilder {
   public static final int CODE_SHELLCLIENT_ABORT_OP = 110;
@@ -38,7 +36,7 @@ public class ResultBuilder {
 
   // errors on member
   public static final int ERRORCODE_PARSING_ERROR = 501;
-  public static final int ERRORCODE_GEMFIRE_ERROR = 505;
+  public static final int ERRORCODE_GEODE_ERROR = 505;
   public static final int ERRORCODE_BADRESPONSE_ERROR = 510;
   public static final int ERRORCODE_BADCONFIG_ERROR = 515;
   public static final int ERRORCODE_USER_ERROR = 520;
@@ -88,17 +86,17 @@ public class ResultBuilder {
   }
 
   /**
    * Method for convenience to create error result for error in GemFire while executing command.
    * <p/>
    * Note: To build your own error result, use {@link #createErrorResultData()} to build
    * {@link ErrorResultData} & then use {@link #buildResult(ResultData)}
    * 
    * @param message Message to be shown to the user
    * @return Result for error in GemFire while executing command.
    */
   public static Result createGemFireErrorResult(String message) {
-    return createErrorResult(ERRORCODE_GEMFIRE_ERROR,
-        "Could not process command due to GemFire error. " + message);
+    return createErrorResult(ERRORCODE_GEODE_ERROR,
+        "Could not process command due to error. " + message);
   }
 
   public static Result createGemFireUnAuthorizedErrorResult(String message) {
@@ -268,7 +266,7 @@ public class ResultBuilder {
       while (result.hasNextLine()) {
         builder.append(result.nextLine());
       }
-      // TODO - Abhishek - what to do with incoming files??
+      // TODO - what to do with incoming files??
     }
 
     return builder.toString();
@@ -88,17 +86,17 @@ public class ResultBuilder {
 
   /**
-   * Method for convenience to create error result for error in GemFire while executing command.
+   * Method for convenience to create error result for error in Geode while executing command.
    * <p/>
    * Note: To build your own error result, use {@link #createErrorResultData()} to build
@@ -88,17 +86,17 @@ public class ResultBuilder {
    * 
    * @param message Message to be shown to the user
-   * @return Result for error in GemFire while executing command.
+   * @return Result for error in Geode while executing command.
    */
   public static Result createGemFireErrorResult(String message) {